@@ -40,9 +40,10 @@ void FreeBusyItemModelTest::testModelValidity()
 
     QVERIFY(model->rowCount() == 0);
 
-    const KDateTime dt1(QDate(2010, 7, 24), QTime(7, 0, 0), KDateTime::UTC);
-    const KDateTime dt2(QDate(2010, 7, 24), QTime(10, 0, 0), KDateTime::UTC);
-    KCalCore::Attendee::Ptr a1(new KCalCore::Attendee(QStringLiteral("fred"), QStringLiteral("fred@example.com")));
+    const QDateTime dt1(QDate(2010, 7, 24), QTime(7, 0, 0), Qt::UTC);
+    const QDateTime dt2(QDate(2010, 7, 24), QTime(10, 0, 0), Qt::UTC);
+    KCalCore::Attendee::Ptr a1(new KCalCore::Attendee(QStringLiteral("fred"), QStringLiteral(
+                                                          "fred@example.com")));
     KCalCore::FreeBusy::Ptr fb1(new KCalCore::FreeBusy());
 
     fb1->addPeriod(dt1, KCalCore::Duration(60 * 60));
@@ -91,14 +92,17 @@ void FreeBusyItemModelTest::testModelValidity2()
     FreeBusyItemModel *model = new FreeBusyItemModel(this);
     new ModelTest(model, this);
 
-    const KDateTime dt1(QDate(2010, 7, 24), QTime(7, 0, 0), KDateTime::UTC);
-    const KDateTime dt2(QDate(2010, 7, 24), QTime(10, 0, 0), KDateTime::UTC);
-    const KDateTime dt3(QDate(2010, 7, 24), QTime(12, 0, 0), KDateTime::UTC);
-    const KDateTime dt4(QDate(2010, 7, 24), QTime(14, 0, 0), KDateTime::UTC);
+    const QDateTime dt1(QDate(2010, 7, 24), QTime(7, 0, 0), Qt::UTC);
+    const QDateTime dt2(QDate(2010, 7, 24), QTime(10, 0, 0), Qt::UTC);
+    const QDateTime dt3(QDate(2010, 7, 24), QTime(12, 0, 0), Qt::UTC);
+    const QDateTime dt4(QDate(2010, 7, 24), QTime(14, 0, 0), Qt::UTC);
 
-    KCalCore::Attendee::Ptr a1(new KCalCore::Attendee(QStringLiteral("fred"), QStringLiteral("fred@example.com")));
-    KCalCore::Attendee::Ptr a2(new KCalCore::Attendee(QStringLiteral("joe"), QStringLiteral("joe@example.com")));
-    KCalCore::Attendee::Ptr a3(new KCalCore::Attendee(QStringLiteral("max"), QStringLiteral("max@example.com")));
+    KCalCore::Attendee::Ptr a1(new KCalCore::Attendee(QStringLiteral("fred"), QStringLiteral(
+                                                          "fred@example.com")));
+    KCalCore::Attendee::Ptr a2(new KCalCore::Attendee(QStringLiteral("joe"), QStringLiteral(
+                                                          "joe@example.com")));
+    KCalCore::Attendee::Ptr a3(new KCalCore::Attendee(QStringLiteral("max"), QStringLiteral(
+                                                          "max@example.com")));
     KCalCore::FreeBusy::Ptr fb1(new KCalCore::FreeBusy());
     KCalCore::FreeBusy::Ptr fb2(new KCalCore::FreeBusy());
     KCalCore::FreeBusy::Ptr fb3(new KCalCore::FreeBusy());
@@ -214,15 +218,16 @@ void FreeBusyItemModelTest::testInsertFreeBusy()
     FreeBusyItemModel *model = new FreeBusyItemModel(this);
     new ModelTest(model, this);
 
-    const KDateTime dt1(QDate(2010, 7, 24), QTime(7, 0, 0), KDateTime::UTC);
-    const KDateTime dt2(QDate(2010, 7, 24), QTime(10, 0, 0), KDateTime::UTC);
-    KCalCore::Attendee::Ptr a1(new KCalCore::Attendee(QStringLiteral("fred"), QStringLiteral("fred@example.com")));
+    const QDateTime dt1(QDate(2010, 7, 24), QTime(7, 0, 0), Qt::UTC);
+    const QDateTime dt2(QDate(2010, 7, 24), QTime(10, 0, 0), Qt::UTC);
+    KCalCore::Attendee::Ptr a1(new KCalCore::Attendee(QStringLiteral("fred"), QStringLiteral(
+                                                          "fred@example.com")));
     KCalCore::FreeBusy::Ptr fb1(new KCalCore::FreeBusy());
     fb1->addPeriod(dt1, KCalCore::Duration(60 * 60));
     fb1->addPeriod(dt2, KCalCore::Duration(60 * 60));
 
-    const KDateTime dt3(QDate(2010, 7, 24), QTime(12, 0, 0), KDateTime::UTC);
-    const KDateTime dt4(QDate(2010, 7, 24), QTime(14, 0, 0), KDateTime::UTC);
+    const QDateTime dt3(QDate(2010, 7, 24), QTime(12, 0, 0), Qt::UTC);
+    const QDateTime dt4(QDate(2010, 7, 24), QTime(14, 0, 0), Qt::UTC);
     KCalCore::FreeBusy::Ptr fb2(new KCalCore::FreeBusy());
     fb2->addPeriod(dt1, KCalCore::Duration(60 * 60));
     fb2->addPeriod(dt2, KCalCore::Duration(60 * 60));
@@ -241,4 +246,3 @@ void FreeBusyItemModelTest::testInsertFreeBusy()
 
     QCOMPARE(model->rowCount(i), 4);
 }
-
