@@ -25,7 +25,6 @@
 #include "utils.h"
 #include "kcalprefs.h"
 
-
 #include <Collection>
 #include <CollectionDialog>
 #include <EntityDisplayAttribute>
@@ -38,8 +37,6 @@
 
 #include <KHolidays/HolidayRegion>
 
-#include <KIdentityManagement/IdentityManager>
-
 #include <KCalCore/CalFilter>
 #include <KCalCore/Event>
 #include <KCalCore/FreeBusy>
@@ -54,9 +51,10 @@
 #include <KCalUtils/ICalDrag>
 #include <KCalUtils/VCalDrag>
 
-#include <KIconLoader>
 #include <KMessageBox>
 #include <KIO/FileCopyJob>
+#include <KIconLoader>
+#include <KLocalizedString>
 
 #include <QUrl>
 #include <QAbstractItemModel>
@@ -66,8 +64,8 @@
 #include <QPointer>
 #include <QFileDialog>
 #include <QUrlQuery>
+#include <QTimeZone>
 
-#include <boost/bind.hpp>
 #include "calendarsupport_debug.h"
 
 using namespace CalendarSupport;
@@ -171,7 +169,7 @@ bool CalendarSupport::hasEvent(const Akonadi::Item &item)
 
 bool CalendarSupport::hasEvent(const KCalCore::Incidence::Ptr &incidence)
 {
-    return incidence && incidence->type() ==  KCalCore::Incidence::TypeEvent;
+    return incidence && incidence->type() == KCalCore::Incidence::TypeEvent;
 }
 
 bool CalendarSupport::hasTodo(const Akonadi::Item &item)
@@ -181,7 +179,7 @@ bool CalendarSupport::hasTodo(const Akonadi::Item &item)
 
 bool CalendarSupport::hasTodo(const KCalCore::Incidence::Ptr &incidence)
 {
-    return incidence && incidence->type() ==  KCalCore::Incidence::TypeTodo;
+    return incidence && incidence->type() == KCalCore::Incidence::TypeTodo;
 }
 
 bool CalendarSupport::hasJournal(const Akonadi::Item &item)
@@ -191,17 +189,16 @@ bool CalendarSupport::hasJournal(const Akonadi::Item &item)
 
 bool CalendarSupport::hasJournal(const KCalCore::Incidence::Ptr &incidence)
 {
-    return incidence && incidence->type() ==  KCalCore::Incidence::TypeJournal;
+    return incidence && incidence->type() == KCalCore::Incidence::TypeJournal;
 }
 
-QMimeData *CalendarSupport::createMimeData(const Akonadi::Item::List &items,
-        const KDateTime::Spec &timeSpec)
+QMimeData *CalendarSupport::createMimeData(const Akonadi::Item::List &items)
 {
     if (items.isEmpty()) {
         return nullptr;
     }
 
-    KCalCore::MemoryCalendar::Ptr cal(new KCalCore::MemoryCalendar(timeSpec));
+    KCalCore::MemoryCalendar::Ptr cal(new KCalCore::MemoryCalendar(QTimeZone::systemTimeZone()));
 
     QList<QUrl> urls;
     int incidencesFound = 0;
@@ -225,23 +222,21 @@ QMimeData *CalendarSupport::createMimeData(const Akonadi::Item::List &items,
     mimeData->setUrls(urls);
 
     KCalUtils::ICalDrag::populateMimeData(mimeData.get(), cal);
-    KCalUtils::VCalDrag::populateMimeData(mimeData.get(), cal);
 
     return mimeData.release();
 }
 
-QMimeData *CalendarSupport::createMimeData(const Akonadi::Item &item,
-        const KDateTime::Spec &timeSpec)
+QMimeData *CalendarSupport::createMimeData(const Akonadi::Item &item)
 {
-    return createMimeData(Akonadi::Item::List() << item, timeSpec);
+    return createMimeData(Akonadi::Item::List() << item);
 }
 
 #ifndef QT_NO_DRAGANDDROP
-QDrag *CalendarSupport::createDrag(const Akonadi::Item &item,
-                                   const KDateTime::Spec &timeSpec, QWidget *parent)
+QDrag *CalendarSupport::createDrag(const Akonadi::Item &item, QWidget *parent)
 {
-    return createDrag(Akonadi::Item::List() << item, timeSpec, parent);
+    return createDrag(Akonadi::Item::List() << item, parent);
 }
+
 #endif
 
 static QByteArray findMostCommonType(const Akonadi::Item::List &items)
@@ -265,11 +260,10 @@ static QByteArray findMostCommonType(const Akonadi::Item::List &items)
 }
 
 #ifndef QT_NO_DRAGANDDROP
-QDrag *CalendarSupport::createDrag(const Akonadi::Item::List &items,
-                                   const KDateTime::Spec &timeSpec, QWidget *parent)
+QDrag *CalendarSupport::createDrag(const Akonadi::Item::List &items, QWidget *parent)
 {
     std::unique_ptr<QDrag> drag(new QDrag(parent));
-    drag->setMimeData(CalendarSupport::createMimeData(items, timeSpec));
+    drag->setMimeData(CalendarSupport::createMimeData(items));
 
     const QByteArray common = findMostCommonType(items);
     if (common == "Event") {
@@ -280,6 +274,7 @@ QDrag *CalendarSupport::createDrag(const Akonadi::Item::List &items,
 
     return drag.release();
 }
+
 #endif
 
 static bool itemMatches(const Akonadi::Item &item, const KCalCore::CalFilter *filter)
@@ -293,17 +288,18 @@ static bool itemMatches(const Akonadi::Item &item, const KCalCore::CalFilter *fi
 }
 
 Akonadi::Item::List CalendarSupport::applyCalFilter(const Akonadi::Item::List &items_,
-        const KCalCore::CalFilter *filter)
+                                                    const KCalCore::CalFilter *filter)
 {
     Q_ASSERT(filter);
     Akonadi::Item::List items(items_);
-    items.erase(std::remove_if(items.begin(), items.end(),
-                               !bind(itemMatches, _1, filter)), items.end());
+    items.erase(std::remove_if(items.begin(), items.end(), [filter](const Akonadi::Item &item) {
+        return !itemMatches(item, filter);
+    }), items.end());
     return items;
 }
 
 bool CalendarSupport::isValidIncidenceItemUrl(const QUrl &url,
-        const QStringList &supportedMimeTypes)
+                                              const QStringList &supportedMimeTypes)
 {
     if (!url.isValid()) {
         return false;
@@ -320,25 +316,26 @@ bool CalendarSupport::isValidIncidenceItemUrl(const QUrl &url)
 {
     return isValidIncidenceItemUrl(url,
                                    QStringList() << KCalCore::Event::eventMimeType()
-                                   << KCalCore::Todo::todoMimeType()
-                                   << KCalCore::Journal::journalMimeType()
-                                   << KCalCore::FreeBusy::freeBusyMimeType());
+                                                 << KCalCore::Todo::todoMimeType()
+                                                 << KCalCore::Journal::journalMimeType()
+                                                 << KCalCore::FreeBusy::freeBusyMimeType());
 }
 
 static bool containsValidIncidenceItemUrl(const QList<QUrl> &urls)
 {
     return
-        std::find_if(urls.begin(), urls.end(),
-                     bind(CalendarSupport::isValidIncidenceItemUrl, _1)) != urls.constEnd();
+        std::find_if(urls.begin(), urls.end(), [](const QUrl &url) {
+        return CalendarSupport::isValidIncidenceItemUrl(url);
+    }) != urls.constEnd();
 }
 
 bool CalendarSupport::canDecode(const QMimeData *md)
 {
     if (md) {
         return
-                containsValidIncidenceItemUrl(md->urls()) ||
-                KCalUtils::ICalDrag::canDecode(md) ||
-                KCalUtils::VCalDrag::canDecode(md);
+            containsValidIncidenceItemUrl(md->urls())
+            || KCalUtils::ICalDrag::canDecode(md)
+            || KCalUtils::VCalDrag::canDecode(md);
     } else {
         return false;
     }
@@ -348,7 +345,7 @@ QList<QUrl> CalendarSupport::incidenceItemUrls(const QMimeData *mimeData)
 {
     QList<QUrl> urls;
     const QList<QUrl> urlsList = mimeData->urls();
-    for (const QUrl &i : urlsList ) {
+    for (const QUrl &i : urlsList) {
         if (isValidIncidenceItemUrl(i)) {
             urls.push_back(i);
         }
@@ -371,17 +368,16 @@ QList<QUrl> CalendarSupport::todoItemUrls(const QMimeData *mimeData)
 
 bool CalendarSupport::mimeDataHasIncidence(const QMimeData *mimeData)
 {
-    return !incidenceItemUrls(mimeData).isEmpty() ||
-           !incidences(mimeData, KDateTime::Spec()).isEmpty();
+    return !incidenceItemUrls(mimeData).isEmpty()
+           || !incidences(mimeData).isEmpty();
 }
 
-KCalCore::Todo::List CalendarSupport::todos(const QMimeData *mimeData,
-        const KDateTime::Spec &spec)
+KCalCore::Todo::List CalendarSupport::todos(const QMimeData *mimeData)
 {
     KCalCore::Todo::List todos;
 
 #ifndef QT_NO_DRAGANDDROP
-    KCalCore::Calendar::Ptr cal(KCalUtils::DndFactory::createDropCalendar(mimeData, spec));
+    KCalCore::Calendar::Ptr cal(KCalUtils::DndFactory::createDropCalendar(mimeData));
     if (cal) {
         const KCalCore::Todo::List calTodos = cal->todos();
         todos.reserve(calTodos.count());
@@ -394,13 +390,12 @@ KCalCore::Todo::List CalendarSupport::todos(const QMimeData *mimeData,
     return todos;
 }
 
-KCalCore::Incidence::List CalendarSupport::incidences(const QMimeData *mimeData,
-        const KDateTime::Spec &spec)
+KCalCore::Incidence::List CalendarSupport::incidences(const QMimeData *mimeData)
 {
     KCalCore::Incidence::List incidences;
 
 #ifndef QT_NO_DRAGANDDROP
-    KCalCore::Calendar::Ptr cal(KCalUtils::DndFactory::createDropCalendar(mimeData, spec));
+    KCalCore::Calendar::Ptr cal(KCalUtils::DndFactory::createDropCalendar(mimeData));
     if (cal) {
         const KCalCore::Incidence::List calIncidences = cal->incidences();
         incidences.reserve(calIncidences.count());
@@ -413,10 +408,9 @@ KCalCore::Incidence::List CalendarSupport::incidences(const QMimeData *mimeData,
     return incidences;
 }
 
-Akonadi::Collection CalendarSupport::selectCollection(QWidget *parent,
-        int &dialogCode,
-        const QStringList &mimeTypes,
-        const Akonadi::Collection &defCollection)
+Akonadi::Collection CalendarSupport::selectCollection(QWidget *parent, int &dialogCode,
+                                                      const QStringList &mimeTypes,
+                                                      const Akonadi::Collection &defCollection)
 {
     QPointer<Akonadi::CollectionDialog> dlg(new Akonadi::CollectionDialog(parent));
     dlg->setWindowTitle(i18n("Select Calendar"));
@@ -453,8 +447,8 @@ Akonadi::Item CalendarSupport::itemFromIndex(const QModelIndex &idx)
 }
 
 Akonadi::Collection::List CalendarSupport::collectionsFromModel(const QAbstractItemModel *model,
-        const QModelIndex &parentIndex,
-        int start, int end)
+                                                                const QModelIndex &parentIndex,
+                                                                int start, int end)
 {
     const int endRow = end >= 0 ? end : model->rowCount(parentIndex) - 1;
     Akonadi::Collection::List collections;
@@ -476,8 +470,8 @@ Akonadi::Collection::List CalendarSupport::collectionsFromModel(const QAbstractI
 }
 
 Akonadi::Item::List CalendarSupport::itemsFromModel(const QAbstractItemModel *model,
-        const QModelIndex &parentIndex,
-        int start, int end)
+                                                    const QModelIndex &parentIndex, int start,
+                                                    int end)
 {
     const int endRow = end >= 0 ? end : model->rowCount(parentIndex) - 1;
     Akonadi::Item::List items;
@@ -546,13 +540,15 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
                     nameStr = cName;
                     typeStr = QStringLiteral("Calendar");
                     break;
-                } else if (tName.startsWith(QStringLiteral("shared.tasks"), Qt::CaseInsensitive) ||
-                           tName.startsWith(QStringLiteral("shared.todo"), Qt::CaseInsensitive)) {
+                } else if (tName.startsWith(QStringLiteral("shared.tasks"), Qt::CaseInsensitive)
+                           || tName.startsWith(QStringLiteral("shared.todo"),
+                                               Qt::CaseInsensitive)) {
                     ownerStr = QStringLiteral("Shared");
                     nameStr = cName;
                     typeStr = QStringLiteral("Tasks");
                     break;
-                } else if (tName.startsWith(QStringLiteral("shared.journal"), Qt::CaseInsensitive)) {
+                } else if (tName.startsWith(QStringLiteral("shared.journal"),
+                                            Qt::CaseInsensitive)) {
                     ownerStr = QStringLiteral("Shared");
                     nameStr = cName;
                     typeStr = QStringLiteral("Journal");
@@ -562,10 +558,10 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
                     nameStr = cName;
                     typeStr = QStringLiteral("Notes");
                     break;
-                } else if (tName != i18n("Calendar") &&
-                           tName != i18n("Tasks") &&
-                           tName != i18n("Journal") &&
-                           tName != i18n("Notes")) {
+                } else if (tName != i18n("Calendar")
+                           && tName != i18n("Tasks")
+                           && tName != i18n("Journal")
+                           && tName != i18n("Notes")) {
                     ownerStr = tName;
                     break;
                 } else {
@@ -580,9 +576,9 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
             if (!ownerStr.compare(QLatin1String("INBOX"), Qt::CaseInsensitive)) {
                 return i18nc("%1 is folder contents",
                              "My Kolab %1", typeStr);
-            } else if (!ownerStr.compare(QLatin1String("SHARED"), Qt::CaseInsensitive) ||
-                       !ownerStr.compare(QLatin1String("CALENDAR"), Qt::CaseInsensitive) ||
-                       !ownerStr.compare(QLatin1String("RESOURCES"), Qt::CaseInsensitive)) {
+            } else if (!ownerStr.compare(QLatin1String("SHARED"), Qt::CaseInsensitive)
+                       || !ownerStr.compare(QLatin1String("CALENDAR"), Qt::CaseInsensitive)
+                       || !ownerStr.compare(QLatin1String("RESOURCES"), Qt::CaseInsensitive)) {
                 return i18nc("%1 is folder name, %2 is folder contents",
                              "Shared Kolab %1 %2", nameStr, typeStr);
             } else {
@@ -590,8 +586,9 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
                     return i18nc("%1 is folder owner name, %2 is folder contents",
                                  "%1's Kolab %2", ownerStr, typeStr);
                 } else {
-                    return i18nc("%1 is folder owner name, %2 is folder name, %3 is folder contents",
-                                 "%1's %2 Kolab %3", ownerStr, nameStr, typeStr);
+                    return i18nc(
+                        "%1 is folder owner name, %2 is folder name, %3 is folder contents",
+                        "%1's %2 Kolab %3", ownerStr, nameStr, typeStr);
                 }
             }
         } else {
@@ -602,8 +599,10 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
 
     // Dav Groupware
     if (resourceName.contains(QStringLiteral("davgroupware"))) {
-        const QString resourceDisplayName = Akonadi::AgentManager::self()->instance(resourceName).name();
-        return i18nc("%1 is the folder name", "%1 in %2", fullCollection.displayName(), resourceDisplayName);
+        const QString resourceDisplayName
+            = Akonadi::AgentManager::self()->instance(resourceName).name();
+        return i18nc("%1 is the folder name", "%1 in %2",
+                     fullCollection.displayName(), resourceDisplayName);
     } //end caldav section
 
     // Google
@@ -632,8 +631,9 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
 
         if (!ownerStr.isEmpty()) {
             const int atChar = ownerStr.lastIndexOf(QLatin1Char('@'));
-            if (atChar >= 0)
+            if (atChar >= 0) {
                 ownerStr.truncate(atChar);
+            }
             if (nameStr.isEmpty()) {
                 return i18nc("%1 is folder owner name, %2 is folder contents",
                              "%1's Google %2", ownerStr, typeStr);
@@ -651,7 +651,8 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
     const QString dName = fullCollection.displayName();
 
     if (!dName.isEmpty()) {
-        return fullCollection.name().startsWith(QStringLiteral("akonadi_")) ? i18n("My %1", dName) : dName;
+        return fullCollection.name().startsWith(QStringLiteral("akonadi_")) ? i18n("My %1",
+                                                                                   dName) : dName;
     } else if (!fullCollection.name().isEmpty()) {
         return fullCollection.name();
     } else {
@@ -664,8 +665,7 @@ QString CalendarSupport::subMimeTypeForIncidence(const KCalCore::Incidence::Ptr
     return incidence->mimeType();
 }
 
-QList<QDate> CalendarSupport::workDays(const QDate &startDate,
-                                       const QDate &endDate)
+QList<QDate> CalendarSupport::workDays(const QDate &startDate, const QDate &endDate)
 {
     QList<QDate> result;
 
@@ -779,7 +779,7 @@ QStringList CalendarSupport::categories(const KCalCore::Incidence::List &inciden
         thisCats = incidence->categories();
         const QStringList::ConstIterator send(thisCats.constEnd());
         for (QStringList::ConstIterator si = thisCats.constBegin();
-                si != send; ++si) {
+             si != send; ++si) {
             if (!cats.contains(*si)) {
                 cats.append(*si);
             }
@@ -788,7 +788,8 @@ QStringList CalendarSupport::categories(const KCalCore::Incidence::List &inciden
     return cats;
 }
 
-bool CalendarSupport::mergeCalendar(const QString &srcFilename, const KCalCore::Calendar::Ptr &destCalendar)
+bool CalendarSupport::mergeCalendar(const QString &srcFilename,
+                                    const KCalCore::Calendar::Ptr &destCalendar)
 {
     if (srcFilename.isEmpty()) {
         qCCritical(CALENDARSUPPORT_LOG) << "Empty filename.";
@@ -799,13 +800,11 @@ bool CalendarSupport::mergeCalendar(const QString &srcFilename, const KCalCore::
         qCCritical(CALENDARSUPPORT_LOG) << "File'" << srcFilename << "' doesn't exist.";
     }
 
-    bool loadedSuccesfully = true;
-
     // merge in a file
     destCalendar->startBatchAdding();
     KCalCore::FileStorage storage(destCalendar);
     storage.setFileName(srcFilename);
-    loadedSuccesfully = storage.load();
+    bool loadedSuccesfully = storage.load();
     destCalendar->endBatchAdding();
 
     return loadedSuccesfully;
